#
# spec file for package unoconv
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           unoconv
Version:        0.9.0
Release:        bp154.1.21
Summary:        Tool to convert between any document format supported by LibreOffice
License:        GPL-2.0-only
Group:          Productivity/File utilities
URL:            http://dag.wieers.com/home-made/unoconv/
Source:         https://github.com/unoconv/unoconv/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Requires:       libreoffice-pyuno
Requires:       python3
BuildArch:      noarch

%description
unoconv converts between any document format that LibreOffice understands.
It uses LibreOffice's UNO bindings for non-interactive conversion of
documents.

Supported document formats include: Open Document Text (.odt),
Open Document Draw (.odd), Open Document Presentation (.odp),
Open Document calc (.odc), MS Word (.doc), MS PowerPoint (.pps/.ppt),
MS Excel (.xls), MS Office Open/OOXML (.xml),
Portable Document Format (.pdf), DocBook (.xml), LaTeX (.ltx),
HTML, XHTML, RTF, Docbook (.xml), GIF, PNG, JPG, SVG, BMP, EPS
and many more...

%prep
%setup -q
sed -i 's|#!%{_bindir}/env python|#!%{_bindir}/python3|g' unoconv

%build

%install
%make_install
make DESTDIR=%{buildroot} install-links
rm -v %{buildroot}%{_bindir}/odt2txt

%files
%license COPYING
%doc AUTHORS CHANGELOG.md ChangeLog README.adoc doc/*.adoc
%{_mandir}/man1/unoconv.1%{?ext_man}
%{_bindir}/*

%changelog
* Sun Mar  8 2020 Adam Mizerski <adam@mizerski.pl>
- update to 0.9.0
  * Much improved MacOS support
  * Better support for newer LibreOffice versions
  * Change default updateDocMode behavior and add new option to keep old behavior
  * Longer timeout for LibreOffice to start on slow systems
  * A fix in error()
  * Add support for Writer EPUB export
  * fix boo#1154818
- update source url
* Thu Jan 10 2019 mardnh@gmx.de
- Update to version 0.8.2
  Changes since 0.7:
  * Add option -M/--meta to add or update document metadata during
    conversion.
  * Add option -I/--input-filter-name to specify input format
  * Dropped support for OpenOffice 3.3 and 3.4
  * Fix for Python 3 to read binary data from stdin
  * Fix for password protected files
  * Make -F switch working for user-defined fields
- Drop patches (not longer needed)
  * 0001-libreoffice-or-OO.o-has-never-had-wps-export.patch
  * 0001-make-LaTeX-export-usable-with-writer2latex-ext.patch
  * 0001-python3-added-compatibility.patch
  * 0001-Updated-ChangeLog.patch
  * 0001-update-FSF-address.patch
  * 0002-remove-export-formats-dropped-by-LibreOffice.patch
- Use tarball from github
* Tue Dec 29 2015 adam@mizerski.pl
- Always include all patches. Just apply them conditionally.
* Mon Dec 28 2015 adam@mizerski.pl
- update to 0.7
  - Changes are in CHANGELOG.md and ChangeLog files.
- pulled patches from Fedora:
  - 0001-libreoffice-or-OO.o-has-never-had-wps-export.patch
  - 0001-make-LaTeX-export-usable-with-writer2latex-ext.patch
  - 0001-python3-added-compatibility.patch
  - this is an update/replacement for unoconv-python3.patch
  - 0001-Updated-ChangeLog.patch
  - 0001-update-FSF-address.patch
  - tweaked last line to make it appliable on unoconv
  - 0002-remove-export-formats-dropped-by-LibreOffice.patch
- made python3 patch be applied also for openSUSE Leap (boo#954814)
* Thu Oct 23 2014 adam@mizerski.pl
- made python3 patch be applied for openSUSE >= 13.2
- removed odt2txt symlink to resolve conflict with odt2txt package
* Sat Oct  4 2014 dimstar@opensuse.org
- Add unoconv-python3.patch: port to python 3. The main integration
  is with libreoffice, which also used python3 by now (boo#899736).
  Patch copied from Fedora.
* Mon Oct 29 2012 adam@mizerski.pl
- update to 0.6
  - Changes are in ChangeLog file
- removed pathes (merged upstream):
  - unoconv-0.4-LD_LIBRARY_PATH.patch
  - unoconv-libreoffice-support.patch
  - unoconv-output-argument.patch
* Wed Dec 14 2011 coolo@suse.com
- COPYING is GPL-2.0+
* Thu Oct 20 2011 adam@mizerski.pl
- fixed bnc#718115
* Thu Oct 20 2011 badshah400@gmail.com
- Added licence header in spec file
- Removed old changelogs from %%changelog section in spec file
* Wed Oct 19 2011 vuntz@opensuse.org
- Add unoconv-libreoffice-support.patch: add support for
  LibreOffice.
- Add unoconv-output-argument.patch: deprecate --outputpath in
  favor of --output, that works in a more reasonable way. Taken
  from git.
* Sat Apr 16 2011 adam@mizerski.pl
- added install-links
* Thu Dec  2 2010 adam@mizerski.pl
- fixed LD_LIBRARY_PATH handling
* Fri Oct 22 2010 adam@mizerski.pl
- update to 0.4
* Tue Apr 27 2010 adam@mizerski.pl
- added unoconv-0.3-ooo_path.patch
- some housekeeping in spec file
